require 'octokit'

module Unlearn
  class RepoDeleter
    attr_reader :repos, :octokit

    def initialize(repos)
      @repos = repos

      login_to_octokit

      @octokit = Octokit::Client.new

      delete_repos
    end

    private

    def login_to_octokit
      Octokit.configure do |c|
        c.login = "Required field, but GitHub doesn't check it when password is a token"
        c.password = Unlearn::GitHubAPI::Token.get
      end
    end

    def delete_repos
      begin
        repos.map do |repo|
          octokit.delete_repository(repo)
        end.all?
      rescue Octokit::Forbidden => e
        puts "Unable to delete repositories. Please check that"
        puts "the 'delete_repo' scope is enabled and try again."
        puts e.documentation_url
        puts "\nGoodbye!"

        exit
      end
    end
  end
end
